@@ -91,7 +91,7 @@ class Commands:
 
     def _run(self, method, args, password_getter):
         cmd = known_commands[method]
-        if cmd.requires_password and self.wallet.use_encryption:
+        if cmd.requires_password and self.wallet.has_password():
             self._password = apply(password_getter,())
             if self._password is None:
                 return
